import { ColorMode, FontFamily, FontSize, FontWeight, LineHeight, Spacing } from '../tokens';
import type { GlobalTheme } from './types';
declare const _default: (theme: GlobalTheme, colorMode: ColorMode) => {
    '*, *::before, *::after': {
        boxSizing: string;
        position: string;
        margin: number;
        minWidth: number;
        minHeight: number;
        padding: number;
        border: number;
        borderRadius: number;
        backgroundColor: string;
        backgroundImage: string;
        backgroundPosition: string;
        backgroundRepeat: string;
    };
    html: {
        backgroundColor: import("csstype").Property.Color | import("csstype").Property.Color[] | import("@theme-ui/css").NestedScaleDict<import("csstype").Property.Color>;
        color: import("csstype").Property.Color | import("csstype").Property.Color[] | import("@theme-ui/css").NestedScaleDict<import("csstype").Property.Color>;
        fontFamily: FontFamily;
        fontWeight: FontWeight;
        fontSize: FontSize;
        lineHeight: LineHeight;
        textAlign: string;
        textSizeAdjust: string;
        WebkitFontSmoothing: string;
        MozOsxFontSmoothing: string;
        colorScheme: string;
        scrollBehavior: string;
        scrollPadding: Spacing;
        '--gds-scrollbar-color': string;
        '--gds-direction': string;
    };
    '[dir="ltr"]': {
        '--gds-direction': string;
    };
    '[dir="rtl"]': {
        '--gds-direction': string;
    };
    "\n  img,\n  svg,\n  video,\n  canvas,\n  audio,\n  iframe,\n  embed,\n  object,\n\n  button,\n  input,\n  select,\n  textarea,\n\n  label,\n  summary\n  ": {
        display: string;
    };
    "\n  img,\n  svg,\n  video,\n  canvas,\n  audio,\n  iframe,\n  embed,\n  object\n  ": {
        verticalAlign: string;
        maxWidth: string;
    };
    "\n  img,\n  svg,\n  video,\n  canvas\n  ": {
        height: string;
    };
    'audio:not([controls])': {
        display: string;
    };
    source: {
        display: string;
    };
    picture: {
        display: string;
    };
    "\n  button,\n  input,\n  select,\n  textarea\n  ": {
        color: string;
        font: string;
        letterSpacing: string;
        textAlign: string;
        textTransform: string;
    };
    textarea: {
        resize: string;
    };
    "\n  button,\n  [role='button'],\n  [type='button'],\n  [type='reset'],\n  [type='submit'],\n  [type='file'],\n  [type='file']::-webkit-file-upload-button\n  ": {
        appearance: string;
        "&:where(:not(:disabled, [aria-disabled='true']))": {
            cursor: string;
        };
    };
    'b, strong': {
        fontWeight: FontWeight;
    };
    a: {
        color: string;
        textDecoration: string;
    };
    'ol, ul, menu': {
        listStyle: string;
    };
    "\n  h1,\n  h2,\n  h3,\n  h4,\n  h5,\n  h6\n  ": {
        fontWeight: string;
        fontSize: string;
    };
    "\n  code,\n  kbd,\n  pre,\n  samp\n  ": {
        fontFamily: string;
    };
    th: {
        fontWeight: string;
    };
    small: {
        fontSize: string;
    };
    "\n  address,\n  cite,\n  dfn,\n  var\n  ": {
        fontStyle: string;
    };
    mark: {
        color: string;
    };
    abbr: {
        textDecoration: string;
    };
    "\n  sub,\n  sup\n  ": {
        verticalAlign: string;
        fontSize: string;
        lineHeight: string;
    };
    sub: {
        bottom: string;
    };
    sup: {
        top: string;
    };
    table: {
        borderCollapse: string;
        borderSpacing: number;
        borderColor: string;
        textIndent: number;
    };
    "\n  th:not([align]),\n  caption:not([align])\n  ": {
        textAlign: string;
    };
    '[hidden]': {
        display: string;
    };
    '*:where(:focus)': {
        outline: string;
    };
    '*:where(:focus-visible)': {
        outline: string;
        outlineOffset: string;
    };
    '.gds-scrollbar-classic': {
        '*::-webkit-scrollbar': {
            width: string;
            height: string;
        };
        '*::-webkit-scrollbar-thumb': {
            backgroundColor: string;
            backgroundClip: string;
            border: string;
            borderRadius: string;
            '&:hover': {
                backgroundColor: string;
            };
            '&:active': {
                borderWidth: string;
                backgroundColor: string;
            };
        };
        '*::-webkit-scrollbar-track': {
            backgroundColor: string;
            borderRadius: string;
            '&:hover': {
                backgroundColor: string;
            };
        };
        '*::-webkit-scrollbar-corner': {
            backgroundColor: string;
        };
    };
};
export default _default;
